@@ -23,6 +23,7 @@ from mrack.outputs.utils import get_external_id
 from mrack.utils import (
     get_fqdn,
     get_host_from_metadata,
+    get_os_type,
     get_password,
     get_shortname,
     get_ssh_key,
@@ -73,7 +74,7 @@ def get_group(inventory, groupname):
         else:
             if "children" in group:
                 found = get_group(group["children"], groupname)
-        if found:
+        if found is not None:
             break
     return found
 
@@ -85,7 +86,7 @@ def add_to_group(inventory, groupname, hostname):
     Returns group or None if it doesn't exist.
     """
     group = get_group(inventory, groupname)
-    if not group:
+    if group is None:
         return None
 
     if "hosts" not in group:
@@ -144,6 +145,7 @@ class AnsibleInventoryOutput:
             "ansible_host": ansible_host,
             "ansible_python_interpreter": python,
             "ansible_user": ansible_user,
+            "meta_os_type": get_os_type(meta_host),
             "meta_fqdn": f"{get_fqdn(name, dom_name)}",
             "meta_hostname": get_shortname(name),
             "meta_domain": f"{get_fqdn(name, dom_name).split('.', 1)[1]}",
@@ -200,12 +202,18 @@ class AnsibleInventoryOutput:
 
         return host_info
 
+    def get_inventory_layout(self):
+        """Get Ansible inventory layout."""
+        layout = self._metadata.get("config", {}).get("ansible", {}).get("layout")
+        if layout is None:
+            return self._config.get("inventory_layout", DEFAULT_INVENTORY_LAYOUT)
+
+        return layout
+
     def create_inventory(self):
         """Create the Ansible inventory in dict form."""
         provisioned = self._db.hosts
-        inventory = deepcopy(
-            self._config.get("inventory_layout", DEFAULT_INVENTORY_LAYOUT)
-        )
+        inventory = deepcopy(self.get_inventory_layout())
         if not isinstance(inventory, dict):
             raise ConfigError("Inventory layout should be a dictionary")
         all_group = ensure_all_group(inventory)
