@@ -29,7 +29,7 @@ from xml.dom.minidom import Document as xml_doc
 
 import yaml
 
-from mrack.errors import ConfigError, MetadataError, ProvisioningError
+from mrack.errors import ConfigError, ProvisioningError
 
 logger = logging.getLogger(__name__)
 
@@ -227,14 +227,14 @@ def fd_open(filename=None):
             file_d.close()
 
 
-def save_yaml(path, yaml_data):
+def save_yaml(path, yaml_data, **kwargs):
     """
     Write yaml data with file.write(yaml.dump()) to file specified by path.
 
     If path is not specified use stdout.
     """
     with fd_open(path) as yaml_file:
-        yaml_file.write(yaml.dump(yaml_data, default_flow_style=False))
+        yaml_file.write(yaml.dump(yaml_data, default_flow_style=False, **kwargs))
 
 
 def object2json(obj):
@@ -277,6 +277,15 @@ def is_windows_host(meta_host):
     )
 
 
+def get_os_type(meta_host):
+    """Get os type from ``os_type`` or infer it from ``os``."""
+    os_type = meta_host.get("os_type")
+    if not os_type:
+        os_type = "linux" if not is_windows_host(meta_host) else "windows"
+
+    return os_type
+
+
 def get_shortname(hostname):
     """
     Get shortname part of fqdn.
@@ -291,13 +300,10 @@ def get_fqdn(hostname, domain):
     Get fqdn from hostname and domain.
 
     Return the hostname if it is fqdn otherwise append domain.
-    @raise: MetadataError when hostname is fqdn that does not belong to domain
     """
     if "." in hostname:
-        if hostname.endswith(domain):
-            return hostname
-        else:
-            raise MetadataError(f"{hostname} does not belong to {domain}.")
+        return hostname
+
     return f"{hostname}.{domain}"
 
 
